package meowlib

import (
	"fmt"
	"time"
)

type InternalServer struct {
	ServerData Server        `json:"server_data,omitempty"`
	Presence   bool          `json:"presence,omitempty"`
	LastCheck  time.Time     `json:"last_check,omitempty"`
	Uptime     time.Duration `json:"uptime,omitempty"`
	Login      string        `json:"login,omitempty"`
	Password   string        `json:"password,omitempty"`
	Me         KeyPair       `json:"me,omitempty"`
}

type ServerList struct {
	Name    string
	Servers []InternalServer
}

func ServerFromUrl(url string) *InternalServer {
	var is InternalServer
	is.ServerData.Url = url
	return &is
}

func (sl *ServerList) AddUrls(urls []string) {
	for _, url := range urls {
		sl.Servers = append(sl.Servers, *ServerFromUrl(url))
	}
}

func (ints *InternalServer) AsymEncryptMessage(Message []byte) (EncryptedMsg []byte, Signature []byte, err error) {
	// prepares a message to send to a specific internal server
	EncryptedMsg, Signature, err = EncryptAndSign(ints.ServerData.PublicKey, ints.Me.Private, Message)
	if err != nil {
		fmt.Println(err.Error())
		return nil, nil, err
	}
	return EncryptedMsg, Signature, err
}

func (ints *InternalServer) AsymDecryptMessage(Message []byte, Signature []byte) (DecryptedMsg []byte, err error) {
	// reads a message from a specific internal server
	DecryptedMsg, err = DecryptAndCheck(ints.Me.Private, ints.ServerData.PublicKey, Message, Signature)
	if err != nil {
		fmt.Println(err.Error())
		return nil, err
	}
	return DecryptedMsg, err
}
